..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Key Terms
---------

============================ ===================================
acyclic graph                edge
adjacency list               edge cost
adjacency matrix             graph
adjacent                     parenthesis property
breadth-first forest         path
breadth-first search (BFS)   shortest path
cycle                        spanning tree
depth-first forest           strongly connected components (SCC)
depth-first search (DFS)     topological sort
digraph                      uncontrolled flooding
directed acyclic graph (DAG) vertex
directed graph               weight
============================ ===================================
